#
# spec file for package skelcd-control-MicroOS
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


######################################################################
#
# IMPORTANT: Please do not change the control file or this spec file
#   in build service directly, use
#   https://github.com/yast/skelcd-control-MicroOS repository
#
#   See https://github.com/yast/.github/blob/master/CONTRIBUTING.md
#   for more details.
#
######################################################################

Name:           skelcd-control-MicroOS
# xmllint (for validation)
BuildRequires:  libxml2-tools
# RNG validation schema


# xsltproc - for building control.TWMicroOS.xml from control.MicroOS.xml
BuildRequires:  libxslt-tools
BuildRequires:  diffutils
# we need to copy some parts from the openSUSE control.xml to MicroOS
BuildRequires:  skelcd-control-openSUSE

######################################################################
#
# Here is the list of Yast packages which are needed in the
# installation system (inst-sys) for the Yast installer
#

# branding
Requires:       yast2-theme
Requires:       yast2-qt-branding-openSUSE

# Generic Yast packages needed for the installer
Requires:       autoyast2
Requires:       yast2-add-on
Requires:       yast2-buildtools
Requires:       yast2-caasp >= 4.2.1
Requires:       yast2-devtools
Requires:       yast2-fcoe-client
# For creating the AutoYast profile at the end of installation (bnc#887406)
Requires:       yast2-firewall
# instsys_cleanup
Requires:       yast2-installation >= 3.1.217.9
Requires:       yast2-iscsi-client
%ifnarch %{arm}
Requires:       yast2-kdump
# yast2-kdump has only runtime dependency but the package is also needed in the inst-sys
Requires:       kdump
%endif
Requires:       yast2-multipath
Requires:       yast2-network >= 3.1.42
Requires:       yast2-nfs-client
Requires:       yast2-ntp-client
Requires:       yast2-proxy
Requires:       yast2-services-manager
Requires:       yast2-slp
Requires:       yast2-trans-stats
Requires:       yast2-tune
Requires:       yast2-update
Requires:       yast2-users
Requires:       yast2-x11
# Ruby debugger in the inst-sys (FATE#318421)
Requires:       rubygem(%{rb_default_ruby_abi}:byebug)
# Install and enable xrdp by default (FATE#320363)
Requires:       yast2-rdp

# Ensure no two skelcd-control-* packages can be installed in the same time,
# an OBS check reports a file conflict for the /CD1/control.xml file from
# the other packages.
Conflicts:      product_control
Provides:       product_control

# we really do not need the YaST packages for building, ignore the dependencies
# to have faster builds and less rebuilds triggered by dependencies
# these are pulled in by the skelcd-control-openSUSE dependencies
#!BuildIgnore: yast2-caasp yast2-branding-openSUSE yast2-qt-branding-openSUSE
#!BuildIgnore: autoyast2 yast2-add-on yast2-buildtools yast2-devtools
#!BuildIgnore: yast2-fcoe-client yast2-firewall
#!BuildIgnore: yast2-installation yast2-iscsi-client yast2-kdump yast2-multipath
#!BuildIgnore: yast2-network yast2-nfs-client yast2-ntp-client yast2-proxy
#!BuildIgnore: yast2-services-manager yast2-slp yast2-trans-stats yast2-tune
#!BuildIgnore: yast2-update yast2-users yast2-x11 yast2-rdp
#!BuildIgnore: yast2-reipl yast2-s390 yast2-vm
#!BuildIgnore: rubygem(%{rb_default_ruby_abi}:byebug)
#!BuildIgnore: yast2-branding-openSUSE-Oxygen yast2-configuration-management
#!BuildIgnore: yast2-core yast2-hardware-detection yast2-installation-control
#!BuildIgnore: yast2-logs yast2-perl-bindings yast2-pkg-bindings yast2-ruby-bindings
#!BuildIgnore: yast2 yast2-ycp-ui-bindings

# Architecture specific packages
#
%ifarch s390 s390x
Requires:       yast2-reipl >= 3.1.4
Requires:       yast2-s390
%endif

%ifarch %ix86 x86_64
Requires:       yast2-vm
%endif

#
######################################################################

URL:            https://github.com/yast/skelcd-control-MicroOS
AutoReqProv:    off
Version:        20230912
Release:        1.4
Summary:        The MicroOS control file needed for installation
License:        MIT
Group:          Metapackages
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         %{name}-%{version}.tar.bz2

%if 0%{?suse_version} >= 1500 && !0%{?skelcd_compat}
%define skelcdpath /usr/lib/skelcd
%endif

%description
The package contains the MicroOS control file needed for installation.

%prep

%setup -n %{name}-%{version}

%build
# build control.TWMicroOS.xml from control.MicroOS.xml
make -C control control.TWMicroOS.xml
# display the changes (just for easier debugging)
# don't fail, a difference is expected
diff -u control/control.MicroOS.xml control/control.TWMicroOS.xml || :

%check
#
# Verify syntax
#
make -C control check

%install
#
# Add control file
#
mkdir -p %{buildroot}/%{?skelcdpath}/CD1
install -m 644 control/control.TWMicroOS.xml %{buildroot}/%{?skelcdpath}/CD1/control.xml

# install LICENSE (required by build service check)
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}
install -m 644 LICENSE %{buildroot}/%{_defaultdocdir}/%{name}

%files
%defattr(644,root,root,755)
%if %{defined skelcdpath}
%dir %{skelcdpath}
%endif
%dir %{?skelcdpath}/CD1
%{?skelcdpath}/CD1/control.xml
%doc %dir %{_defaultdocdir}/%{name}
%license %{_defaultdocdir}/%{name}/LICENSE

%changelog
* Tue Sep 12 2023 Fabian Vogt <fvogt@suse.com>
- Set readonly_language to false for desktop roles (boo#1212560)
- 20230912
* Wed May 24 2023 Stefan Schubert <schubi@suse.com>
- Removed bootloader from default patterns. (jsc#PED-1906)
- 20230524
* Wed Jan 25 2023 Josef Reidinger <jreidinger@suse.com>
- drop unused proposals definition ( related to drop of yast2-sound
  bsc#1206903)
- 20230125
* Thu Oct 27 2022 Shawn W Dunn <sfalken@cloverleaf-linux.org>
- Desktop-KDE: Changed polkit profile to match Gnome, for continuity
  (boo#1205348)
- 20221205
* Thu Oct 27 2022 Richard Brown <rbrown@suse.com>
- Desktop-GNOME: Use easy polkit profile (boo#1204792)
- 20221027
* Thu Oct 27 2022 Fabian Vogt <fvogt@suse.com>
- Fix syntax of additional_dialogs (boo#1202852)
- 20221026
* Thu Sep 29 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable kdump for %%arm - boo#1203888
- 20221010
* Wed Aug 10 2022 Richard Brown <rbrown@suse.com>
- Added "inst_microos" role to Desktop roles (boo#1202067)
- 20220810
* Tue Jul 26 2022 Ladislav Slezák <lslezak@suse.cz>
- Added "kdump" dependency, yast2-kdump only has a runtime
  depenency but the package is also needed in the inst-sys
  (related to bsc#1199840)
- 20220726
* Mon Jul 25 2022 Shawn W Dunn <sfalken@cloverleaf-linux.org>
- Update MicroOS KDE Pattern to use transactional-update (boo#1201874)
- 20220725
* Thu Jul 14 2022 Richard Brown <rbrown@suse.com>
- Restore KDE Desktop as Alpha (boo#1201049)
- 20220714
* Thu Jun 30 2022 Richard Brown <rbrown@suse.com>
- Flag GNOME Desktop as RC, remove KDE Desktop (boo#1201049)
- 20220630
* Fri Feb  4 2022 Richard Brown <rbrown@suse.com>
- Use NetworkManager always (boo#1172684)
- 20220204
* Tue Jan 25 2022 Alberto Planas Dominguez <aplanas@suse.com>
- Remove ALPHA tag for the Keylime services
- Reference the new place for the configuration file
  (gh#skelcd-control-MicroOS#49).
- 20220125
* Mon Jan 24 2022 David Diaz <dgonzalez@suse.com>
- Add bootloader pattern for all roles (gh#yast/skelcd-control-MicroOS#47).
  Sent by Alberto Planas <aplanas@suse.com>.
- 20220124
* Tue Dec 28 2021 Knut Anderssen <kanderssen@suse.com>
- Added 'lsm' section for selecting and configuring the desired
  Linux Security Module (jsc#SLE-22069)
- 20211228
* Tue Sep  7 2021 Knut Anderssen <kanderssen@suse.com>
- Define default NTP servers for MicroOS (bsc#1180699)
- 20210907
* Mon Jun 28 2021 Alberto Planas Dominguez <aplanas@suse.com>
- Add remote attestation roles: micro_os_role_ra_{agent,verifier} (bsc#1187796)
- 20210628
* Wed Jun  2 2021 Stefan Schubert <schubi@suse.de>
- Enable ipv4_forward and ipv6_forward for ALL roles (bsc#1186280).
- 20210602
* Mon Mar 29 2021 Neal Gompa <ngompa13@gmail.com>
- Evaluate security module before software module and
  stop force-installing SELinux (boo#1183804)
- 20210329
* Fri Mar 26 2021 Neal Gompa <ngompa13@gmail.com>
- Mark GNOME Desktop variant as beta-quality (boo#1184037)
- 20210326
* Tue Mar 23 2021 Neal Gompa <ngompa13@gmail.com>
- Replace installing AppArmor patterns with SELinux ones to
  work around broken yast-security behavior (boo#1183804)
- Enable SELinux again (jsc#SMO-20)
- 20210323.2
* Tue Mar 23 2021 Neal Gompa <ngompa13@gmail.com>
- Install AppArmor patterns again and temporarily revert enabling
  SELinux by default to unblock other MicroOS stuff (boo#1183804)
- 20210323.1
* Tue Mar 23 2021 Neal Gompa <ngompa13@gmail.com>
- Stop force-installing AppArmor (boo#1183894)
- 20210323
* Mon Mar 22 2021 Dario Faggioli <dfaggioli@suse.com>
- Enable COW for /home on GNOME and KDE Desktop
- 20210322
* Mon Mar  1 2021 David Diaz <dgonzalez@suse.com>
- Set SELinux enforcing mode by default (jsc#SMO-20) .
- Use the new security proposal client (jsc#SLE-15840,
  jsc#SLE-17307).
- 20210303
* Tue Feb 23 2021 Neal Gompa <ngompa13@gmail.com>
- Declare package manager patterns for each MicroOS role (boo#1182803)
- 20210222
* Thu Nov 26 2020 Richard Brown <rbrown@suse.de>
- Correct MicroOS Desktop Polkit rules (boo#1163453)
- 20201126
* Tue Nov 17 2020 Richard Brown <rbrown@suse.de>
- Normalise & correct minimum partition requirements (boo#1178895)
- 20201117
* Wed Sep 23 2020 Jan Engelhardt <jengelh@inai.de>
- Modernize specfile: avoid mixing old $RPM_* shell vars
  and macros.
* Wed Jul 29 2020 schubi@suse.de
- Removed unneeded AY installation step "autoimage" (bsc#1140711).
- 20200729
* Wed Jul  1 2020 Richard Brown <rbrown@suse.de>
- Remove tmp subvolume for transactional systems [boo#1173461][jsc#PM-1898]
- 20200701
* Mon May 11 2020 Steffen Winterfeldt <snwint@suse.com>
- remove obsolete proposal_settings_editable (bsc#1171423)
- 20200511
* Tue Mar 17 2020 rbrown@suse.de
- Remove microos_apparmor from default system role [boo#1166857]
- 20200317
* Wed Feb 12 2020 rbrown@suse.de
- Add microos-gnome- and -kde-desktop roles [boo#1163453]
- 20200211
* Thu Aug 15 2019 kukuk@suse.de
- Require yast2-caasp >= 4.2.1
- Add NTP configuration dialog [bsc#1135342]
- 20190815
* Fri Aug  2 2019 Richard Brown <rbrown@suse.de>
- Add /usr/local subvolume [boo#1143682]
- Fix indentation
- 20190802
* Wed Jun 19 2019 Richard Brown <rbrown@suse.de>
- Add /boot/writable subvolume [boo#1138725]
- 20190619
* Thu Jun 13 2019 Richard Brown <rbrown@suse.de>
- Add srv as a subvolume [boo#1132436]
- Select product on installation [boo#1124590]
- 20190613
* Tue Apr 16 2019 Richard Brown <rbrown@suse.de>
- Actually Fix MicroOS Container Host description [boo#1131975]
- 20190416
* Tue Apr  9 2019 Richard Brown <rbrown@suse.de>
- Fix MicroOS Container Host description [boo#1131975]
- 20190409
* Fri Apr  5 2019 Richard Brown <rbrown@suse.de>
- Use new patterns-microos pattern names [boo#1131700]
- 20190405
* Wed Mar 13 2019 Richard Brown <rbrown@suse.de>
- Inital Version
- 20190313
